@@ -52,9 +52,11 @@
 #' plot(subgrp.model, type = "boxplot")
 #'
 #' plot(subgrp.model, type = "interaction")
+#'
+#' plot(subgrp.model, type = "conditional")
 #' @export
 plot.subgroup_fitted <- function(x,
-                                 type = c("boxplot", "density", "interaction"),
+                                 type = c("boxplot", "density", "interaction", "conditional"),
                                  avg.line = TRUE,
                                  ...)
 {
@@ -66,13 +68,13 @@ plot.subgroup_fitted <- function(x,
 
     outcome.lab <- "Outcome"
 
+    benefit.scores <- x$benefit.scores
+    B              <- NROW(benefit.scores)
+
     if (type != "interaction")
     {
         if (is.null(x$call)) stop("retcall argument must be set to TRUE for fitted model object")
 
-        benefit.scores <- x$benefit.scores
-        B <- NROW(benefit.scores)
-
         res.2.plot <- array(NA, dim = c(B, 3))
         colnames(res.2.plot) <- c("Recommended", "Received", "Value")
         res.2.plot <- data.frame(res.2.plot)
@@ -104,7 +106,7 @@ plot.subgroup_fitted <- function(x,
                                                    ncol(avg.res$avg.outcomes)),
                                  Value       = as.vector(avg.res$avg.outcomes))
 
-    Recommended <- Received <- Value <- NULL
+    Recommended <- Received <- Value <- bs <- Outcome <- NULL
 
 
 
@@ -151,6 +153,53 @@ plot.subgroup_fitted <- function(x,
                 ylab(outcome.lab) +
                 ggtitle("Individual Observations Among Subgroups")
         }
+    } else if (type == "conditional")
+    {
+        if (!is.null(x$trt.received))
+        {
+            trt <- x$trt.received
+        } else if (!is.null(x$call))
+        {
+            trt <- x$call$trt
+        } else
+        {
+            stop("Refit model and plot again.")
+        }
+
+        if (!is.null(x$y))
+        {
+            y <- x$y
+        } else if (!is.null(x$call))
+        {
+            y <- x$call$y
+        } else
+        {
+            stop("Refit model and plot again.")
+        }
+        res.2.plot <- data.frame(bs = benefit.scores, Received = trt, Outcome = y)
+        if (x$family == "binomial")
+        {
+            pl.obj <- ggplot(res.2.plot,
+                             aes(x = bs, y = Outcome,
+                                 group = factor(Received),
+                                 color = factor(Received) )) +
+                geom_point() +
+                geom_smooth(method = "gam", method.args = list(family = "binomial")) +
+                theme(legend.position = "bottom") +
+                scale_color_discrete(name = "Received") +
+                ggtitle("Individual Observations by Treatment Group")
+        } else
+        {
+            pl.obj <- ggplot(res.2.plot,
+                             aes(x = bs, y = Outcome,
+                                 group = factor(Received),
+                                 color = factor(Received) )) +
+                geom_point() +
+                geom_smooth(method = "gam") +
+                theme(legend.position = "bottom") +
+                scale_color_discrete(name = "Received") +
+                ggtitle("Individual Observations by Treatment Group")
+        }
     } else
     {
         pl.obj <- ggplot(avg.res.2.plot,
